js.bootstrap_image_gallery
==========================

Introduction
------------

This library packages `Bootstrap Image Gallery`_ for `fanstatic`_.

.. _`fanstatic`: http://fanstatic.org
.. _`Bootstrap Image Gallery`: http://blueimp.github.com/Bootstrap-Image-Gallery/

This requires integration between your web framework and ``fanstatic``,
and making sure that the original resources (shipped in the ``resources``
directory in ``js.bootstrap_image_gallery``) are published to some URL.

